@@ -4,6 +4,7 @@
 # See the NOTICE for more information.
 
 from collections import deque
+from multiprocessing.util import register_after_fork
 import logging
 import atexit
 import time
@@ -93,6 +94,12 @@ class Agent(object):
     def pending(self):
         return len(self.queue)
 
+    def after_fork(self):
+        self.log.debug("restarting background processes after fork")
+        self.config_fetcher = None
+        self.consumer = None
+        self.link_service()
+
     def link_service(self):
         if self.config_fetcher is None:
             self.config_fetcher = ConfigFetcher(cfg)
@@ -130,3 +137,4 @@ pending = agent.pending
 cfg = agent.cfg
 
 atexit.register(unlink_service)
+register_after_fork(agent, Agent.after_fork)
